import axios from 'axios';
import {
    Message
} from 'element-ui'
import router from '../router/index'
import Cookie from 'js-cookie'
import config from '@/config'

const service = axios.create({
    baseURL: config.host,
    timeout: 10000000
})

// post请求头
service.defaults.headers.post['Content-Type'] = 'application/json;charset=UTF-8';
// 请求拦截器
service.interceptors.request.use(config => {
    const token = Cookie.get('admin-token')
    if (token) {
      config.headers.token = token
    }
    return config;
  }, err => {
    Message.error({
      message: '退出登陆',
      onClose: function () {
        router.push({name: 'login'});
      }
    })
    return Promise.reject(err);
})

// 响应拦截器
service.interceptors.response.use(
    response => {
        const res = response.data;
        if (res.status == 200 || res.status == 10000 || res.status == 30001) {
            return Promise.resolve(res).catch(e => {});
        } else if (!res.status) {
            return Promise.resolve(res).catch(e => {});
        } else {
            Message.error(res.message)
            return Promise.reject(res)
        }
    },
    // 服务器状态码不是200的情况
    error => {
        if (error.response.status) {
            switch (error.response.status) {
                // 401: 未登录
                case 401:
                    Message.error('登录过期，请重新登录')
                    setTimeout(() => {
                        history.back()
                    }, 1500)
                    break;
                default:
                    // Message.error(error.response.data.message)
                    Promise.reject(error.response);
            }
            return Promise.reject(error.response);
        }
    }
);

function get(url, params) {
    return new Promise((resolve, reject) => {
        service.get(url, { params: params }).then(res => {
            resolve(res);
        }).catch(err => {
            reject(err);
        });
    });
}

function post(url, params) {
    return new Promise((resolve, reject) => {
        service.post(url, params).then(res => {
            resolve(res);
        }).catch(err => {
            reject(err.data);
        });
    });
}

function del(url, params) {
    return new Promise((resolve, reject) => {
        service.delete(url, {
            params
        }).then(res => {
            resolve(res);
        }).catch(err => {
            reject(err.data);
        });
    });
}

function put(url, params) {
    return new Promise((resolve, reject) => {
        service.put(url, params).then(res => {
            resolve(res);
        }).catch(err => {
            reject(err.data);
        });
    });
}

export { get, post, del, put }